@@ -142,7 +142,8 @@ class Tagger:
             y_pred,
             y_scores,
             num_features,
-            {k:len(v) for k,v in data_sample.items()}
+            {k:len(v) for k,v in data_sample.items()},
+            list(data_sample.keys())
         )
         # update model & report
         self.model = model
